@@ -55,7 +55,7 @@ class DataFrameResource(BaseResource):
         mediatype = self._media_type(self._fmt)
 
         return {
-            "name": self.formatted_resource_name(),
+            "name": self._resource_name,
             "description": self._resource_description,
             "path": self._resource_path(),
             "format": self._fmt,
